#-*- coding:utf-8 -*-
"""
@Author: SunYiTan
@Date: 2020/7/31 15:19
@LastEditTime: 2020/7/31 15:19
@LastEditors: SunYiTan
@Description: 
"""

def add(x,y):
    return x+y

def division(x,y):
    return x/y

def mutiply(x,y):
    return x*y

def subtract(x,y):
    return x-y

def main():
    pass

if __name__ == '__main__':
    main()